@@ -23,10 +23,12 @@ class MorningstarDeDownloader:
             raise ValueError(f"Namespace not sent for {symbol}")
 
         codes = {
+            "BVME:DEM": "0P00015909",
             "BVME:EMCR": "0P0000YWT1",
             "BVME:DGSE": "0P0001590A",
             "AMS:VUCP": "0P00017M0P",
             "FWB:VUKE": "0P0001BVG4",
+            "FWB:XUHY": "0P0001CP30",
             "AMS:VUTY": "0P00017M0O",
             "XETRA:WTES": "0P00015GSJ"
         }
